Documentation
¶
Index ¶
Constants ¶
const TEST_DENOM = "atest"
Variables ¶
This section is empty.
Functions ¶
func NewRootCmd ¶
NewRootCmd creates a new root command for evmd. It is called once in the main function.
func NewTestNetworkFixture ¶
func NewTestNetworkFixture() sdknetwork.TestFixture
NewTestNetworkFixture returns a new evmd AppConstructor for network simulation tests
func NewTestnetCmd ¶
func NewTestnetCmd(mbm module.BasicManager, genBalIterator banktypes.GenesisBalancesIterator, appCreator appCreator) *cobra.Command
NewTestnetCmd creates a root testnet command with subcommands to: 1. run an in-process testnet or 2. initialize validator configuration files for running a multi-validator testnet in a separate process or 3. update application and consensus state with the local validator info
Types ¶
Click to show internal directories.
Click to hide internal directories.