Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func EndSpanErr ¶
EndSpanErr records the error to the span if not nil, and then ends the span. NOTE: This should be called like so:
defer func() { EndSpanErr(span, err) }
and not like this:
defer EndSpanErr(span, err)
This is due to the fact that the latter captures the error value at the point in time of the defer line, whilst the former will capture the final error value at the very end of the function.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.