GO-2025-3684: Cosmos EVM Allows Partial Precompile State Writes in github.com/cosmos/evm
package
Version:
v0.7.0
Opens a new window with list of versions in this module.
Published: May 5, 2026
License: Apache-2.0
Opens a new window with license information.
Imports: 9
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type Queue[Tx any] struct {
}
Queue asynchronously inserts batches of txs in FIFO order.
New creates a new queue. name distinguishes this queue's metrics from other
queue instances (e.g. "evm" vs "cosmos").
func (iq *Queue[Tx]) Close()
Close stops the main loop of the queue.
Push enqueues a Tx's to eventually be inserted. Returns a channel that will
have an error pushed to it if an error occurs inserting the Tx.
Source Files
¶
Click to show internal directories.
Click to hide internal directories.